@@ -1,19 +1,18 @@
 program example_log_gamma
-  use stdlib_kinds, only: dp
+  use stdlib_kinds, only: sp, dp
   use stdlib_specialfunctions_gamma, only: log_gamma
   implicit none
 
   integer :: i
   real :: x
   real(dp) :: y
-  complex :: z
-  complex(dp) :: z1
+  complex(sp) :: z
 
   i = 10
   x = 8.76
   y = x
   z = (5.345, -3.467)
-  z1 = z
+
   print *, log_gamma(i)     !default single precision output
 !12.8018274
 
@@ -29,7 +28,4 @@ program example_log_gamma
 
 !(2.56165648, -5.73382425)
 
-  print *, log_gamma(z1)
-
-!(2.5616575105114614, -5.7338247782852498)
 end program example_log_gamma
